@@ -1,40 +1,32 @@
-use strict;
-use warnings;
-
 package Test::NoWarnings;
 
+use 5.006;
+use strict;
+use warnings;
+use Carp;
+use Exporter ();
 use Test::Builder;
-
 use Test::NoWarnings::Warning;
 
+use vars qw( $VERSION @EXPORT_OK @ISA $do_end_test );
+BEGIN {
+	$VERSION   = '1.00';
+	@ISA       = 'Exporter';
+	@EXPORT_OK = qw(
+		clear_warnings had_no_warnings warnings
+	);
+}
+
 my $Test = Test::Builder->new;
 my $PID = $$;
-
-use Carp;
-
-use vars qw(
-	$VERSION @EXPORT_OK @ISA $do_end_test
-);
-
-$VERSION = '0.083';
-
-require Exporter;
-@ISA = qw( Exporter );
-
-@EXPORT_OK = qw(
-	clear_warnings had_no_warnings warnings
-);
-
 my @warnings;
 
 $SIG{__WARN__} = make_catcher(\@warnings);
 
 $do_end_test = 0;
 
-sub import
-{
+sub import {
 	$do_end_test = 1;
-
 	goto &Exporter::import;
 }
 
@@ -45,12 +37,10 @@ END {
 	had_no_warnings() if $do_end_test;
 }
 
-sub make_warning
-{
+sub make_warning {
 	local $SIG{__WARN__};
 
-	my $msg = shift;
-
+	my $msg     = shift;
 	my $warning = Test::NoWarnings::Warning->new;
 
 	$warning->setMessage($msg);
@@ -65,12 +55,10 @@ sub make_warning
 	return $warning;
 }
 
-sub make_catcher
-{
-	# this make a subroutine which can be used in $SIG{__WARN__}
-	# it takes one argument, a ref to an array
-	# it will push the details of the warning onto the end of the array.
-
+# this make a subroutine which can be used in $SIG{__WARN__}
+# it takes one argument, a ref to an array
+# it will push the details of the warning onto the end of the array.
+sub make_catcher {
 	my $array = shift;
 
 	return sub {
@@ -84,8 +72,7 @@ sub make_catcher
 	};
 }
 
-sub had_no_warnings
-{
+sub had_no_warnings {
 	return 0 if $$ != $PID;
 
 	local $SIG{__WARN__};
@@ -93,15 +80,12 @@ sub had_no_warnings
 
 	my $ok;
 	my $diag;
-	if (@warnings == 0)
-	{
+	if ( @warnings == 0 ) {
 		$ok = 1;
-	}
-	else
-	{
+	} else {
 		$ok = 0;
 		$diag = "There were ".@warnings." warning(s)\n";
-		$diag .= join("----------\n", map { $_->toString } @warnings);
+		$diag .= join "----------\n", map { $_->toString } @warnings;
 	}
 
 	$Test->ok($ok, $name) || $Test->diag($diag);
@@ -109,23 +93,19 @@ sub had_no_warnings
 	return $ok;
 }
 
-sub clear_warnings
-{
+sub clear_warnings {
 	local $SIG{__WARN__};
 	@warnings = ();
 }
 
-sub warnings
-{
+sub warnings {
 	local $SIG{__WARN__};
 	return @warnings;
 }
 
-sub builder
-{
+sub builder {
 	local $SIG{__WARN__};
-	if (@_)
-	{
+	if ( @_ ) {
 		$Test = shift;
 	}
 	return $Test;
@@ -135,6 +115,8 @@ sub builder
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Test::NoWarnings - Make sure you didn't emit any warnings while testing
@@ -295,11 +277,13 @@ L<Test::Builder>, L<Test::Warn>
 
 =head1 AUTHOR
 
-Written by Fergal Daly <fergal@esatclear.ie>.
+Fergal Daly E<lt>fergal@esatclear.ieE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2003 by Fergal Daly E<lt>fergal@esatclear.ieE<gt>.
+Copyright 2003 - 2007 Fergal Daly.
+
+Some parts copyright 2010 Adam Kennedy.
 
 This program is free software and comes with no warranty. It is distributed
 under the LGPL license
